TPT_demo: Demo TPT

View source: R/demo.R

TPT_demoR Documentation

Demo TPT

Description

This function launches a demo for the TPT

Usage

TPT_demo(
  take_training = TRUE,
  admin_password = "demo",
  researcher_email = "longgold@gold.uc.ak",
  dict = tptR::TPT_dict,
  language = "en",
  feedback = TRUE
)

Arguments

take_training

(Boolean scalar) Defines whether instructions and training are included. Defaults to TRUE.

admin_password

(Scalar character) Password for accessing the admin panel. Defaults to "demo".

researcher_email

(Scalar character) If not NULL, this researcher's email address is displayed at the bottom of the screen so that online participants can ask for help. Defaults to longgold@gold.uc.ak, the email address of this package's developer.

dict

The psychTestR dictionary used for internationalisation.

language

The language you want to run your demo in. Possible languages include English ("en") and German (informal "de", formal "de_f"). The first language is selected by default

feedback

(Function) Defines the feedback to give the participant at the end of the test. Defaults to a graph-based feedback page.

...

Further arguments to be passed to TPT().


harin-git/tptR documentation built on June 1, 2022, 1:39 p.m.