| TPT_demo | R Documentation |
This function launches a demo for the TPT
TPT_demo( take_training = TRUE, admin_password = "demo", researcher_email = "longgold@gold.uc.ak", dict = tptR::TPT_dict, language = "en", feedback = TRUE )
take_training |
(Boolean scalar) Defines whether instructions and training are included. Defaults to TRUE. |
admin_password |
(Scalar character) Password for accessing the admin panel.
Defaults to |
researcher_email |
(Scalar character)
If not |
dict |
The psychTestR dictionary used for internationalisation. |
language |
The language you want to run your demo in.
Possible languages include English ( |
feedback |
(Function) Defines the feedback to give the participant at the end of the test. Defaults to a graph-based feedback page. |
... |
Further arguments to be passed to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.